..
    Names are in alphabetical order

Maintainers
-----------

- `Philip Loche`_
- `Alexander Schlaich`_
- Henrik Stooß

.. _Philip Loche: https://people.epfl.ch/philip.loche
.. _Alexander Schlaich:  https://tuhh.de/ipfm/people/schlaich

Developers
----------

- Maximilian Becker
- `Simon Gravelle`_
- Philipp Stärk
- Srihas Velpuri

.. _Simon Gravelle: https://simongravelle.github.io/

Contributors
------------

- Adyant Agrawal
- Shane Carlson
- Kira Fischer
- Federico Grasselli
- Julian Kappler
- Marc Sauter
- Laura Scalfi
- Julius Schulz
- Dominik Wille
- Amanuel Wolde-Kidan
